@@ -13,7 +13,7 @@ package Lemonldap::NG::Manager;
 use 5.10.0;
 use utf8;
 use Mouse;
-our $VERSION = '1.9.7';
+our $VERSION = '1.9.8';
 use Lemonldap::NG::Common::Conf::Constants;
 use Lemonldap::NG::Common::PSGI::Constants;
 
@@ -105,6 +105,20 @@ sub init {
     1;
 }
 
+sub tplParams {
+    return ( VERSION => $VERSION, );
+}
+
+sub javascript {
+    my ($self) = @_;
+    return
+      'var formPrefix=staticPrefix+"forms/";var confPrefix=scriptname+"confs/";'
+      . ( $self->links ? 'var links=' . JSON::to_json( $self->links ) . ';' : '' )
+      . ( $self->menuLinks
+        ? 'var menulinks=' . JSON::to_json( $self->menuLinks ) . ';'
+        : '' );
+}
+
 1;
 __END__
 
