@@ -181,6 +181,10 @@
       $scope.showModal('message.html');
     };
 
+    $scope.downloadConf = function(c, $scope) {
+      window.open($scope.confPrefix + $scope.currentCfg.cfgNum + '?full');
+    };
+
     $scope.save = function() {
       $scope.showModal('save.html').then(function() {
         $scope.waiting = true;
@@ -345,6 +349,18 @@
       });
     };
 
+    /* Add host*/
+    $scope.addHost = function(cn, scope) {
+      if (!cn.data) cn.data = [];
+      cn.data.push({
+        "k": "newHost",
+        h: [{
+          "k": "key",
+          "v": "uid"
+        }]
+      });
+    };
+
     /* SAML attribute entry */
     $scope.addSamlAttribute = function() {
       var node = $scope._findContainer();
@@ -916,6 +932,14 @@
         type: type
       }), filename);
     };
+
+    /* Save as pem, text */
+    $scope.saveAsPem = function(cs, scope) {
+      scope.saveAs(cs.data[0].data + "\n" + cs.data[2].data, 'application/x-pem-file', cs.title + ".pem");
+    };
+    $scope.saveAsText = function(cs, scope) {
+      scope.saveAs(cs.data, 'text/plain', cs.title + ".txt");
+    };
   }]);
 
 })();
\ No newline at end of file
